aerosoltools.aerosol2d.Aerosol2D.convert\_to\_surface\_concentration
====================================================================

.. currentmodule:: aerosoltools.aerosol2d

.. automethod:: Aerosol2D.convert_to_surface_concentration